==> draw-0.3.2.tar.gz: test/comment/comment_test.dart <==
// Copyright (c) 2017, the Dart Reddit API Wrapper project authors.
// Please see the AUTHORS file for details. All rights reserved.
// Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.

import 'dart:async';
import 'dart:io';

import 'package:test/test.dart';
import 'package:draw/draw.dart';

import '../test_utils.dart';

Future prettyPrint(comments, depth) async {
  if (comments == null) {
    return;
  }
  for (var i = 0; i < comments.length; ++i) {
    final tabs = '$depth \t' * depth;
    final comment = comments[i];
    if (comment is MoreComments) {
      await prettyPrint(await comment.comments(), depth);
    } else {
      final body = (await comment.body ?? 'Null');
      print(tabs + body);
      await prettyPrint(comment.replies, depth + 1);
    }
  }
}

// Note: these tests are skipped on Windows due to issues with line endings.
// TODO(bkonyi): fix these tests on Windows at some point?
Future main() async {
  test('lib/comment/continue_test', () async {
    final reddit =
        await createRedditTestInstance('test/comment/continue_test.json');
    final submission = await reddit.submission(id: '7czz1q').populate();
    final comments = submission.comments;
    final printer = () async {
      await prettyPrint(comments, 0);
    };

    var output = "";
    await runZoned(printer, zoneSpecification:
        new ZoneSpecification(print: (self, parent, zone, message) {
      output += message + '\n';
    }));
    final actual =
        new File('test/comment/continue_test_expected.out').readAsStringSync();
    expect(output, equals(actual));
  }, skip: Platform.isWindows);

  test('lib/comment/tons_of_comments_test', () async {
    final reddit = await createRedditTestInstance(
        'test/comment/tons_of_comments_test.json');
    final submission = await reddit.submission(id: '7gylz9').populate();
    final comments = submission.comments;
    final printer = () async {
      await prettyPrint(comments, 0);
    };

    var output = "";
    var count = 0;
    await runZoned(printer, zoneSpecification:
        new ZoneSpecification(print: (self, parent, zone, message) {
      count++;
      output += "$count" + message + '\n';
    }));
    final actual = new File('test/comment/tons_of_comments_expected.out')
        .readAsStringSync();
    expect(output, equals(actual));
  }, skip: Platform.isWindows);

  test('lib/comment/comment_ref_test', () async {
    final reddit =
        await createRedditTestInstance('test/comment/comment_ref_test.json');
    final comment = await reddit.comment(id: 'dxj0i8m').populate();
    final commentWithPath = await reddit
        .comment(
            url:
                'https://www.reddit.com/r/pics/comments/8cz8v0/owls_born_outside_of_office_window_wont_stop/dxj0i8m/')
        .populate();

    expect(
        comment.body, '“ ok class, everyone have a look into our Humanarium”');
    expect(commentWithPath.body, comment.body);
    expect(commentWithPath.id, comment.id);
    expect(comment.id, 'dxj0i8m');
    expect(comment.submission.shortlink, commentWithPath.submission.shortlink);
  });
}

==> draw-0.3.3.tar.gz: test/comment/comment_test.dart <==
// Copyright (c) 2017, the Dart Reddit API Wrapper project authors.
// Please see the AUTHORS file for details. All rights reserved.
// Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.

import 'dart:async';
import 'dart:io';

import 'package:test/test.dart';
import 'package:draw/draw.dart';

import '../test_utils.dart';

Future<void> prettyPrint(comments, depth) async {
  if (comments == null) {
    return;
  }
  for (var i = 0; i < comments.length; ++i) {
    final tabs = '$depth \t' * depth;
    final comment = comments[i];
    if (comment is MoreComments) {
      await prettyPrint(await comment.comments(), depth);
    } else {
      final body = (await comment.body ?? 'Null');
      print(tabs + body);
      await prettyPrint(comment.replies, depth + 1);
    }
  }
}

// Note: these tests are skipped on Windows due to issues with line endings.
// TODO(bkonyi): fix these tests on Windows at some point?
Future<void> main() async {
  test('lib/comment/continue_test', () async {
    final reddit =
        await createRedditTestInstance('test/comment/continue_test.json');
    final submission = await reddit.submission(id: '7czz1q').populate();
    final comments = submission.comments;
    final printer = () async {
      await prettyPrint(comments, 0);
    };

    var output = "";
    await runZoned(printer, zoneSpecification:
        new ZoneSpecification(print: (self, parent, zone, message) {
      output += message + '\n';
    }));
    final actual =
        new File('test/comment/continue_test_expected.out').readAsStringSync();
    expect(output, equals(actual));
  }, skip: Platform.isWindows);

  test('lib/comment/tons_of_comments_test', () async {
    final reddit = await createRedditTestInstance(
        'test/comment/tons_of_comments_test.json');
    final submission = await reddit.submission(id: '7gylz9').populate();
    final comments = submission.comments;
    final printer = () async {
      await prettyPrint(comments, 0);
    };

    var output = "";
    var count = 0;
    await runZoned(printer, zoneSpecification:
        new ZoneSpecification(print: (self, parent, zone, message) {
      count++;
      output += "$count" + message + '\n';
    }));
    final actual = new File('test/comment/tons_of_comments_expected.out')
        .readAsStringSync();
    expect(output, equals(actual));
  }, skip: Platform.isWindows);

  test('lib/comment/comment_ref_test', () async {
    final reddit =
        await createRedditTestInstance('test/comment/comment_ref_test.json');
    final comment = await reddit.comment(id: 'dxj0i8m').populate();
    final commentWithPath = await reddit
        .comment(
            url:
                'https://www.reddit.com/r/pics/comments/8cz8v0/owls_born_outside_of_office_window_wont_stop/dxj0i8m/')
        .populate();

    expect(
        comment.body, '“ ok class, everyone have a look into our Humanarium”');
    expect(commentWithPath.body, comment.body);
    expect(commentWithPath.id, comment.id);
    expect(comment.id, 'dxj0i8m');
    expect(comment.submission.shortlink, commentWithPath.submission.shortlink);
  });

  test('lib/comment/comment_properties_test', () async {
    final reddit =
        await createRedditTestInstance('test/comment/continue_test.json');
    final submission = await reddit.submission(id: '7czz1q').populate();
    final comment = submission.comments[0] as Comment;

    expect(comment.approved, isFalse);
    expect(comment.approvedAtUtc, isNull);
    expect(comment.approvedBy, isNull);
    expect(comment.archived, isFalse);
    expect(comment.authorFlairText, isNull);
    expect(comment.bannedAtUtc, isNull);
    expect(comment.bannedBy, isNull);
    expect(comment.canGild, isFalse);
    expect(comment.canModPost, isTrue);
    expect(comment.collapsed, isFalse);
    expect(comment.collapsedReason, isNull);
    expect(
        comment.createdUtc,
        new DateTime.fromMillisecondsSinceEpoch(1510703692 * 1000,
            isUtc: true));
    expect(comment.depth, 0);
    expect(comment.downvotes, 0);
    expect(comment.edited, isFalse);
    expect(comment.ignoreReports, isFalse);
    expect(comment.isSubmitter, isTrue);
    expect(comment.vote, VoteState.upvoted);
    expect(comment.linkId, 't3_7czz1q');
    expect(comment.numReports, 0);
    expect(comment.parentId, 't3_7czz1q');
    expect(comment.permalink,
        '/r/drawapitesting/comments/7czz1q/testing/dpty59t/');
    expect(comment.removalReason, isNull);
    expect(comment.removed, isFalse);
    expect(comment.saved, isFalse);
    expect(comment.score, 1);
    expect(comment.scoreHidden, isFalse);
    expect(comment.spam, isFalse);
    expect(comment.stickied, isFalse);
    expect(comment.subreddit, reddit.subreddit('drawapitesting'));
    expect(comment.subredditId, 't5_3mqw1');
    expect(comment.subredditType, 'restricted');
    expect(comment.upvotes, 1);
    expect(comment.isRoot, isTrue);
  });
}
